<?php
/**
 * Functions and definitions
 *
 * @package WordPress
 * @subpackage Jane
 * @since Jane 1.0
  */
  
if ( ! isset( $content_width ) ) {
	$content_width = 987;
}
function jane_setup() {

	load_theme_textdomain( 'jane', get_template_directory() . '/languages' );
	
	add_theme_support( 'automatic-feed-links' );

	add_theme_support( 'custom-background', array(
		'default-color' => '02050c',
	) );

	add_theme_support( 'post-thumbnails' );
	
	set_post_thumbnail_size( 300, 9999 ); 
	
		$args = array(
		'default-text-color'     => 'fff',
		'height'                 => 300,
		'width'                  => 300,
		'wp-head-callback'       => 'jane_header_style',
		'admin-head-callback'    => 'jane_admin_header_style',
		'admin-preview-callback' => 'jane_admin_header_image',

	);
	add_theme_support( 'custom-header', $args );
	
	register_nav_menu( 'primary', __( 'Primary Menu', 'jane' ));
	
	/*
	 * Enable support for Post Formats.
	 */
	add_theme_support( 'post-formats', array(
		'gallery', 'video'
	) );
	
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'caption'
	) );
	
	/*
	 * Enable support for woocommerce (hide non-support message).
	 */
	 
	add_theme_support( 'woocommerce' );
}
add_action( 'after_setup_theme', 'jane_setup' );

if ( ! function_exists( 'jane_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 * 
 */
function jane_header_style() {
	$text_color = get_header_textcolor();

	if ( display_header_text() && $text_color === get_theme_support( 'custom-header', 'default-text-color' ) )
		return;

	// If we get this far, we have custom styles.
	?>
	<style type="text/css" id="jane-header-css">
	<?php
		// Has the text been hidden?
		if ( ! display_header_text() ) :
	?>
		.site-title,
		.site-description {
			clip: rect(1px 1px 1px 1px); /* IE7 */
			clip: rect(1px, 1px, 1px, 1px);
			position: absolute;
		}
	<?php
		// If the user has set a custom color for the text, use that.
		elseif ( $text_color != get_theme_support( 'custom-header', 'default-text-color' ) ) :
	?>
		.site-title a {
			color: #<?php echo esc_attr( $text_color ); ?>;
		}
	<?php endif; ?>
	</style>
	<?php
}
endif;
if ( ! function_exists( 'jane_admin_header_style' ) ) :
/**
 * Style the header image displayed on the Appearance > Header screen.
 *
 * @since Jane 1.0
 */
function jane_admin_header_style() {
?>
	<style type="text/css" id="jane-admin-header-css">
	.appearance_page_custom-header #headimg {
		background: #02050c;
		border: none;
		width: 302px;
	}
	#headimg h1 {
		font-family: 'Tangerine', sans-serif;
		font-size: 40px;
		margin-bottom: 0;
		text-align: center;
	}
	#headimg h1 a {
		color: #fff;
		text-decoration: none;
	}
	#headimg .site-description {
		color: #ccccff;
		text-align: center;
		font-size: 14px;
		margin-top: 0;
		margin-bottom: 20px;
	}
	#headimg img {
		border-radius: 200px;
		vertical-align: middle;
	}
	</style>
<?php
}
endif; 

if ( ! function_exists( 'jane_admin_header_image' ) ) :
/**
 * Create the custom header image markup displayed on the Appearance > Header screen.
 *
 * @since Jane 1.0
 */
function jane_admin_header_image() {
?>
	<div id="headimg">
		<h1 class="displaying-header-text"><a id="name"<?php echo sprintf( ' style="color:#%s;"', get_header_textcolor() ); ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
		<h2 class="displaying-header-text site-description"><?php bloginfo( 'description' ); ?></h2>
		<?php if ( get_header_image() ) : ?>
		<img src="<?php header_image(); ?>" alt="">
		<?php endif; ?>
	</div>
<?php
}
endif;

/**
 * Load our special font CSS file.
 *
 */
function jane_custom_header_fonts() {
	$font_url = jane_get_font_url();
	if ( ! empty( $font_url ) )
		wp_enqueue_style( 'jane-fonts', esc_url_raw( $font_url ), array(), null );
}
add_action( 'admin_print_styles-appearance_page_custom-header', 'jane_custom_header_fonts' );

/**
 * Return the Google font stylesheet URL if available.
 */
function jane_get_font_url() {
	$font_url = '';

	/* translators: If there are characters in your language that are not supported
	 * by fonts, translate this to 'off'. Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Tangerine font: on or off', 'jane' ) ) {
		$subsets = 'latin,latin-ext';
		$family = 'Tangerine';

		/* translators: To add an additional Tangerine character subset specific to your language,
		
		 * translate this to 'greek', 'cyrillic' or 'vietnamese'. Do not translate into your own language.
		 */
		$subset = _x( 'no-subset', 'Tangerine font: add new subset (greek, cyrillic, vietnamese)', 'jane' );

		if ( 'cyrillic' == $subset )
			$subsets .= ',cyrillic,cyrillic-ext';
		elseif ( 'greek' == $subset )
			$subsets .= ',greek,greek-ext';
		elseif ( 'vietnamese' == $subset )
			$subsets .= ',vietnamese';

		$query_args = array(
			'family' => $family,
			'subset' => $subsets,
		);
		$font_url = add_query_arg( $query_args, "//fonts.googleapis.com/css" );
		
	}

	return $font_url;
}
/**
 * Enqueue scripts and styles for front-end.
 */
function jane_scripts_styles() {
	global $wp_styles;
	
	$font_url = jane_get_font_url();
	if ( ! empty( $font_url ) )
		wp_enqueue_style( 'jane-fonts', esc_url_raw( $font_url ), array(), null );
		
	// Loads our main stylesheet.
	wp_enqueue_style( 'jane-style', get_stylesheet_uri() );
			
	// Loads the Internet Explorer specific stylesheet.
	wp_enqueue_style( 'jane-ie', get_template_directory_uri() . '/css/ie.css', array( 'jane-style' ), '20141010' );
	$wp_styles->add_data( 'jane-ie', 'conditional', 'lt IE 9' );
	
	/*
	 * Adds JavaScript to pages with the comment form to support
	 * sites with threaded comments (when in use).
	 */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );
		
	// Adds JavaScript for handing the navigation menu hide-and-show behavior. 
	wp_enqueue_script( 'jane-navigation', get_template_directory_uri() . '/js/navigation.js', array( 'jquery' ), '20141201', true );
	
}
add_action( 'wp_enqueue_scripts', 'jane_scripts_styles' );

/**
 * Add Editor styles and fonts to Tiny MCE
 *
 * @since Jane 1.2
 */
function jane_add_editor_styles() {
	add_editor_style( 'css/editor-style.css' );
	
	$font_url = jane_get_font_url();
	if ( ! empty( $font_url ) )
		 add_editor_style( $font_url );
}
add_action( 'after_setup_theme', 'jane_add_editor_styles' );
 
/**
 * Extend the default WordPress body classes.
 *
 * @param array $classes Existing class values.
 * @return array Filtered class values.
 */
function jane_body_class( $classes ) {

	// Enable custom font class only if the font CSS is queued to load.
	if ( wp_style_is( 'jane-fonts', 'queue' ) )
		$classes[] = 'google-fonts-on';
		
	return $classes;
}
add_filter( 'body_class', 'jane_body_class' );

/**
 * Create a nicely formatted and more specific title element text for output
 * in head of document, based on current view.
 *
 * @since Jane 1.0
 *
 * @param string $title Default title text for current view.
 * @param string $sep Optional separator.
 * @return string The filtered title.
 */
function jane_wp_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() ) {
		return $title;
	}

	// Add the site name.
	$title .= get_bloginfo( 'name', 'display' );

	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) ) {
		$title = "$title $sep $site_description";
	}

	if ( $paged >= 2 || $page >= 2 ) {
		$title = "$title $sep " . sprintf( __( 'Page %s', 'jane' ), max( $paged, $page ) );
	}

	return $title;
}
add_filter( 'wp_title', 'jane_wp_title', 10, 2 );
/**
 * Register sidebars and widgetized areas.
 *
 * @since Jane 1.0
 */
function jane_widgets_init() {

	register_sidebar( array(
		'name' => __( 'Main Sidebar', 'jane' ),
		'id' => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => __( 'Top Sidebar', 'jane' ),
		'id' => 'sidebar-2',
		'before_widget' => '<div class="widget-wrap"><aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside></div>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => __( 'Footer Sidebar', 'jane' ),
		'id' => 'sidebar-3',
		'before_widget' => '<div class="widget-wrap"><aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside></div>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'jane_widgets_init' );

if ( ! function_exists( 'jane_post_nav' ) ) :
/**
 * Display navigation to next/previous post.
 *
 * @since Jane 1.0
 */
function jane_post_nav() {
	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}

	?>
	<nav class="navigation post-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Post navigation', 'jane' ); ?></h1>
		<div class="nav-link">
			<?php
			if ( is_attachment() ) :
				previous_post_link( '%link', __( '<span class="meta-nav">Published In</span>%title', 'jane' ) );
			else :
				$next = next_post_link( '%link ', __( '<span class="nav-next">%title &rarr;</span>', 'jane' ) );
				if ( $next ) :
					previous_post_link( '%link', __( '<span class="nav-previous">&larr; %title</span>', 'jane' ) );
					$next;
				else :
					previous_post_link( '%link', __( '<span class="nav-previous-one">&larr; %title</span>', 'jane' ) );
				endif;
				
			endif;
			?>
		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<div class="clear-right"></div>
	<?php
}
endif;

if ( ! function_exists( 'jane_paging_nav' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @since Jane 1.0
 */
function jane_paging_nav() {

	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}

	$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
	$pagenum_link = html_entity_decode( get_pagenum_link() );
	$query_args   = array();
	$url_parts    = explode( '?', $pagenum_link );

	if ( isset( $url_parts[1] ) ) {
		wp_parse_str( $url_parts[1], $query_args );
	}

	$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
	$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

	$format  = $GLOBALS['wp_rewrite']->using_index_permalinks() && ! strpos( $pagenum_link, 'index.php' ) ? 'index.php/' : '';
	$format .= $GLOBALS['wp_rewrite']->using_permalinks() ? user_trailingslashit( 'page/%#%', 'paged' ) : '?paged=%#%';

	$links = paginate_links( array(
		'base'     => $pagenum_link,
		'format'   => $format,
		'total'    => $GLOBALS['wp_query']->max_num_pages,
		'current'  => $paged,
		'mid_size' => 1,
		'add_args' => array_map( 'urlencode', $query_args ),
		'prev_text' => __( '&larr; Previous', 'jane' ),
		'next_text' => __( 'Next &rarr;', 'jane' ),
	) );

	if ( $links ) :

	?>
	<nav class="navigation paging-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Posts navigation', 'jane' ); ?></h1>
		<div class="pagination loop-pagination">
			<?php echo $links; ?>
		</div><!-- .pagination -->
	</nav><!-- .navigation -->
	<?php
	endif;
	
}
endif;

if ( ! function_exists( 'jane_the_attached_image' ) ) :
/**
 * Print the attached image with a link to the next attached image.
 *
 * @since Jane 1.0
 */
function jane_the_attached_image() {
	$post                = get_post();

	$attachment_size     = apply_filters( 'jane_attachment_size', array( 1027, 1027 ) );
	$next_attachment_url = wp_get_attachment_url();

	$attachment_ids = get_posts( array(
		'post_parent'    => $post->post_parent,
		'fields'         => 'ids',
		'numberposts'    => -1,
		'post_status'    => 'inherit',
		'post_type'      => 'attachment',
		'post_mime_type' => 'image',
		'order'          => 'ASC',
		'orderby'        => 'menu_order ID',
	) );

	// If there is more than 1 attachment in a gallery...
	if ( count( $attachment_ids ) > 1 ) {
		foreach ( $attachment_ids as $attachment_id ) {
			if ( $attachment_id == $post->ID ) {
				$next_id = current( $attachment_ids );
				break;
			}
		}

		// get the URL of the next image attachment...
		if ( $next_id ) {
			$next_attachment_url = get_attachment_link( $next_id );
		}

		// or get the URL of the first image attachment.
		else {
			$next_attachment_url = get_attachment_link( array_shift( $attachment_ids ) );
		}
	}

	printf( '<a href="%1$s" rel="attachment">%2$s</a>',
		esc_url( $next_attachment_url ),
		wp_get_attachment_image( $post->ID, $attachment_size )
	);
}
endif;

/**
 * Add new wrapper for woocommerce pages.
 *
 * @since Jane 1.2
 */

remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);

add_action('woocommerce_before_main_content', 'jane_wrapper_start', 10);
add_action('woocommerce_after_main_content', 'jane_wrapper_end', 10);

function jane_wrapper_start() {
  echo '<div id="woocommerce-wrapper">';
}

function jane_wrapper_end() {
  echo '</div>';
}

/**
 * Create not empty title for archive
 *
 * @since Jane 1.4
 *
 * @param string $title Default title text.
 * @param int $id.
 * @return string The filtered title.
 */
function jane_title( $title, $id = null ) {

    if ( trim($title) == '' && ( is_archive() || is_search() || is_home() ) ) {
        return esc_html( get_the_date() );
    }

    return $title;
}
add_filter( 'the_title', 'jane_title', 10, 2 );